#include <stdio.h>
#include <math.h>
#include <gtk/gtk.h>

#include <gtk-hst/graph.h>
#include <gtk-hst/gtkhistogram.h>

GtkWidget *create_mainWindow(void);

GPrintFunc std_logger;
void my_logger(const gchar *string)
{
    printf("[mylogger]%s\n", string);
}

static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
{
    /* Do not destroy with a delete-event */
    return TRUE;
}

int main(int argc, char *argv[])
{
    GtkWidget *mainWindow;
    int iid;

    //std_logger = g_set_printerr_handler( my_logger );

    gtk_init(&argc, &argv);

    mainWindow = create_mainWindow();

    gtk_dialog_run(GTK_DIALOG(mainWindow));
    return 0;
}

GtkWidget * create_mainWindow(void)
{
    GtkWidget *mainWindow;
    GtkWidget *frmGraph, *label, *hst1d;
    HstGraph *graph;
    double *xv, *yv, t;
    int ipt, npts=250;

    mainWindow = gtk_dialog_new_with_buttons("H2D", NULL,
                                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, 
                                             GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
                                             NULL);

    frmGraph = gtk_frame_new(NULL);
    gtk_container_add(GTK_CONTAINER (GTK_DIALOG(mainWindow)->vbox), frmGraph);
    gtk_frame_set_shadow_type(GTK_FRAME (frmGraph), GTK_SHADOW_IN);
    label = gtk_label_new("A Graph");
    gtk_frame_set_label_widget(GTK_FRAME (frmGraph), label);
    xv = g_new(double, npts);
    yv = g_new(double, npts);
    for (ipt=0, t=0.; ipt<npts; ipt++, t+=0.5e-9)
    {
        double xx = 2.*(t-30e-9)/25e-9;
        if (xx>=0)
        {
            yv[ipt] = 10.e-7 * pow(xx/2., 2)*exp(2.-xx) + 1.e-5;
        }
        else
            yv[ipt] = 1.e-5;

        yv[ipt] *= -1;
        xv[ipt] = t;
    }
    graph = hst_graph_new(npts, xv, yv);
    hst1d = gtk_hst1d_new( HST_FUNCTION(graph));
    gtk_hst1d_set_xtitle(GTK_HST1D(hst1d), "X axis");
    gtk_hst1d_set_ytitle(GTK_HST1D(hst1d), "Y axis");
    gtk_container_add(GTK_CONTAINER (frmGraph), hst1d);
    g_free(xv);
    g_free(yv);

    gtk_widget_show_all(mainWindow);
    return mainWindow;
}
